@@ -57,45 +57,47 @@ rasterToPolygons <- function(x, fun=NULL, n=4, na.rm=TRUE, digits=12, dissolve=F
 	colnames(xyv) <- c('x', 'y', names(x))
 	if (nrow(xyv) == 0) {
 		warning('no values in selection')
-		NULL
+		return( NULL )
 	}
 	
-	xr <- xres(x)/2
-	yr <- yres(x)/2
+	cr <- .getPolygons(xyv[, 1:2, drop=FALSE], res(x), n)
+	
+	# xr <- xres(x)/2
+	# yr <- yres(x)/2
 
-	if (n==4) {
-		cr <- matrix(ncol=10, nrow=nrow(xyv))
-		cr[,c(1,4:5)] <- xyv[,1] - xr
-		cr[,2:3] <- xyv[,1] + xr
-		cr[,c(6:7,10)] <- xyv[,2] + yr
-		cr[,8:9] <- xyv[,2] - yr
-	} else if (n == 8) {
-		cr <- matrix(ncol=18, nrow=nrow(xyv))
-		cr[,c(1,7:9)] <- xyv[,1] - xr
-		cr[,c(2,6)] <- xyv[,1] 
-		cr[,3:5] <- xyv[,1] + xr
-		cr[,c(10:12,18)] <- xyv[,2] + yr
-		cr[,c(13:17)] <- xyv[,2] 
-		cr[,14:16] <- xyv[,2] - yr
-	} else if (n == 16) {
-		cr <- matrix(ncol=34, nrow=nrow(xyv))
-		cr[,c(1,13:17)] <- xyv[,1] - xr
-		cr[,c(2,12)] <- xyv[,1] - 0.5 * xr
-		cr[,c(3,11)] <- xyv[,1] 
-		cr[,c(4,10)] <- xyv[,1] + 0.5 * xr
-		cr[,5:9] <- xyv[,1] + xr
+	# if (n==4) {
+		# cr <- matrix(ncol=10, nrow=nrow(xyv))
+		# cr[,c(1,4:5)] <- xyv[,1] - xr
+		# cr[,2:3] <- xyv[,1] + xr
+		# cr[,c(6:7,10)] <- xyv[,2] + yr
+		# cr[,8:9] <- xyv[,2] - yr
+	# } else if (n == 8) {
+		# cr <- matrix(ncol=18, nrow=nrow(xyv))
+		# cr[,c(1,7:9)] <- xyv[,1] - xr
+		# cr[,c(2,6)] <- xyv[,1] 
+		# cr[,3:5] <- xyv[,1] + xr
+		# cr[,c(10:12,18)] <- xyv[,2] + yr
+		# cr[,c(13,17)] <- xyv[,2] 
+		# cr[,14:16] <- xyv[,2] - yr
+	# } else if (n == 16) {
+		# cr <- matrix(ncol=34, nrow=nrow(xyv))
+		# cr[,c(1,13:17)] <- xyv[,1] - xr
+		# cr[,c(2,12)] <- xyv[,1] - 0.5 * xr
+		# cr[,c(3,11)] <- xyv[,1] 
+		# cr[,c(4,10)] <- xyv[,1] + 0.5 * xr
+		# cr[,5:9] <- xyv[,1] + xr
 		
-		cr[,c(18:22,34)] <- xyv[,2] + yr
-		cr[,c(23,33)] <- xyv[,2] + 0.5 * yr
-		cr[,c(24,32)] <- xyv[,2] 
-		cr[,c(25,31)] <- xyv[,2] - 0.5 * yr
-		cr[,26:30] <- xyv[,2] - yr
-	}
+		# cr[,c(18:22,34)] <- xyv[,2] + yr
+		# cr[,c(23,33)] <- xyv[,2] + 0.5 * yr
+		# cr[,c(24,32)] <- xyv[,2] 
+		# cr[,c(25,31)] <- xyv[,2] - 0.5 * yr
+		# cr[,26:30] <- xyv[,2] - yr
+	# }
 	cr <- round(cr, digits=digits)
 	
-	sp <- lapply(1:nrow(cr), function(i) Polygons(list(Polygon( matrix( cr[i,], ncol=2 ) )), i))
-	sp <- SpatialPolygons(sp, proj4string=projection(x, FALSE))
-	sp <- SpatialPolygonsDataFrame(sp, data.frame(xyv[,3:ncol(xyv),drop=FALSE]), match.ID=FALSE)
+	sp <- lapply(1:nrow(cr), function(i) sp::Polygons(list(sp::Polygon( matrix( cr[i,], ncol=2 ) )), i))
+	sp <- sp::SpatialPolygons(sp,  proj4string=.getCRS((x)))
+	sp <- sp::SpatialPolygonsDataFrame(sp, data.frame(xyv[,3:ncol(xyv),drop=FALSE]), match.ID=FALSE)
 	if (dissolve) {
 		if(! requireNamespace("rgeos") ) {
 			warning('package rgeos is not available. Cannot dissolve')
